#ifndef vi322_H
#define vi322_H

typedef enum {
  SEGMENT_COLON = 15,
  SEGMENT_SINE_WAVE = 16,
  SEGMENT_UP_ARROW = 17,
  SEGMENT_MINUS = 18,   
  SEGMENT_LEADING_1 = 28,
  SEGMENT_DP_4 = 29,
  SEGMENT_PLUS_COLON = 30,
  SEGMENT_BAT = 31
} vi_322_segment;

void vi_322_segment_on(int segment);
void vi_322_segment_off(int segment);
void vi_322_segment_toggle(int segment);
void vi_322_show_digit(int digit, int pos);
void vi_322_blank_digit(int pos);
void vi_322_show_number(int i);

#endif

